diff src/cpu/sparc/vm/nativeInst_sparc.hpp @ 6725:da91efe96a93

6964458: Reimplement class meta-data storage to use native memory Summary: Remove PermGen, allocate meta-data in metaspace linked to class loaders, rewrite GC walking, rewrite and rename metadata to be C++ classes Reviewed-by: jmasa, stefank, never, coleenp, kvn, brutisso, mgerdin, dholmes, jrose, twisti, roland Contributed-by: jmasa <jon.masamitsu@oracle.com>, stefank <stefan.karlsson@oracle.com>, mgerdin <mikael.gerdin@oracle.com>, never <tom.rodriguez@oracle.com>
author coleenp
date Sat, 01 Sep 2012 13:25:18 -0400
parents 1d1603768966
children f0c2369fda5a
line wrap: on
line diff
--- a/src/cpu/sparc/vm/nativeInst_sparc.hpp	Fri Aug 31 16:39:35 2012 -0700
+++ b/src/cpu/sparc/vm/nativeInst_sparc.hpp	Sat Sep 01 13:25:18 2012 -0400
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2012, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -246,7 +246,7 @@
     assert(is_op2(*(unsigned int *)pc, Assembler::sethi_op2), "must be sethi");
     intptr_t hi = (intptr_t)gethi( (unsigned int *)pc );
     intptr_t lo = (intptr_t)get_simm13(arith_insn);
-    assert((unsigned)lo < (1 << 10), "offset field of set_oop must be 10 bits");
+    assert((unsigned)lo < (1 << 10), "offset field of set_metadata must be 10 bits");
     return hi | lo;
   }
 
@@ -261,7 +261,7 @@
     assert(is_op2(sethi_insn, Assembler::sethi_op2), "must be sethi");
     int hi = Assembler::inv_hi22(sethi_insn);
     int lo = get_simm13(arith_insn);
-    assert((unsigned)lo < (1 << 10), "offset field of set_oop must be 10 bits");
+    assert((unsigned)lo < (1 << 10), "offset field of set_metadata must be 10 bits");
     return hi | lo;
   }
 
@@ -508,9 +508,9 @@
 
 #endif // _LP64
 
 // An interface for accessing/manipulating native set_oop imm, reg instructions.
 // (used to manipulate inlined data references, etc.)
-//      set_oop imm, reg
+//      set_metadata imm, reg
 //      == sethi %hi22(imm), reg ;  add reg, %lo10(imm), reg
 class NativeMovConstReg;
 inline NativeMovConstReg* nativeMovConstReg_at(address address);
@@ -564,9 +564,9 @@
 };
 
 
 // An interface for accessing/manipulating native set_oop imm, reg instructions.
 // (used to manipulate inlined data references, etc.)
-//      set_oop imm, reg
+//      set_metadata imm, reg
 //      == sethi %hi22(imm), reg; nop; add reg, %lo10(imm), reg
 //
 // Note that it is identical to NativeMovConstReg with the exception of a nop between the
@@ -508,9 +508,9 @@
 #endif // _LP64
 
-// An interface for accessing/manipulating native set_oop imm, reg instructions.
+// An interface for accessing/manipulating native set_metadata imm, reg instructions.
 // (used to manipulate inlined data references, etc.)
@@ -564,9 +564,9 @@
 
 
-// An interface for accessing/manipulating native set_oop imm, reg instructions.
+// An interface for accessing/manipulating native set_metadata imm, reg instructions.
 // (used to manipulate inlined data references, etc.)